@@ -14,11 +14,10 @@
 
 import time
 
-from oslo_log import log as logging
-
 from murano.api import v1
 from murano.common import wsgi
 from murano.db.services import stats
+from murano.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 
@@ -35,7 +34,7 @@ class RequestStatisticsCollection(object):
         self.average_time = (self.average_time * self.request_count +
                              ex_time) / (self.request_count + 1)
         if tenant:
-            tenant_count = self.requests_per_tenant.get(tenant, 0)  # nosec
+            tenant_count = self.requests_per_tenant.get(tenant, 0)
             tenant_count += 1
             self.requests_per_tenant[tenant] = tenant_count
 
@@ -55,15 +54,13 @@ def stats_count(api, method):
                 ts = time.time()
                 result = func(*args, **kwargs)
                 te = time.time()
-                tenant = args[1].context.project_id
+                tenant = args[1].context.tenant
                 update_count(api, method, te - ts,
                              tenant)
                 return result
             except Exception:
                 te = time.time()
-                tenant = args[1].context.project_id
-                LOG.exception('API {api} method {method} raised an '
-                              'exception'.format(api=api, method=method))
+                tenant = args[1].context.tenant
                 update_error_count(api, method, te - te, tenant)
                 raise
         return wrap
@@ -72,15 +69,17 @@ def stats_count(api, method):
 
 
 def update_count(api, method, ex_time, tenant=None):
-    LOG.debug("Updating count stats for {api}, {method} on object {object}"
-              .format(api=api, method=method, object=v1.stats))
+    LOG.debug("Updating count stats for %s, %s on object %s" % (api,
+                                                                method,
+                                                                v1.stats))
     v1.stats.add_api_request(tenant, ex_time)
     v1.stats.request_count += 1
 
 
 def update_error_count(api, method, ex_time, tenant=None):
-    LOG.debug("Updating count stats for {api}, {method} on object "
-              "{object}".format(api=api, method=method, object=v1.stats))
+    LOG.debug("Updating count stats for %s, %s on object %s" % (api,
+                                                                method,
+                                                                v1.stats))
     v1.stats.add_api_error(tenant, ex_time)
     v1.stats.error_count += 1
     v1.stats.request_count += 1
