@@ -14,16 +14,15 @@
 
 import os
 import uuid
+import zipfile
 
-from nose.plugins.attrib import attr as tag
-from tempest.lib import exceptions
 from tempest.test import attr
+from tempest_lib import exceptions
 
 from murano.tests.functional.api import base
-import murano.tests.functional.common.zip_utils_mixin as zip_utils
 
 
-class TestCaseRepository(base.TestCase, zip_utils.ZipUtilsMixin):
+class TestCaseRepository(base.TestCase):
 
     @classmethod
     def setUpClass(cls):
@@ -33,7 +32,15 @@ class TestCaseRepository(base.TestCase, zip_utils.ZipUtilsMixin):
         cls.location = os.path.realpath(
             os.path.join(os.getcwd(), os.path.dirname(__file__)))
 
-        cls.zip_dir(cls.location, "DummyTestApp")
+        __folderpath__ = os.path.join(cls.location, "DummyTestApp")
+        __rootlen__ = len(__folderpath__) + 1
+
+        with zipfile.ZipFile(os.path.join(cls.location,
+                                          "DummyTestApp.zip"), "w") as zf:
+            for dirname, _, files in os.walk(__folderpath__):
+                for filename in files:
+                    fn = os.path.join(dirname, filename)
+                    zf.write(fn, fn[__rootlen__:])
 
     def setUp(self):
         super(TestCaseRepository, self).setUp()
@@ -59,7 +66,6 @@ class TestCaseRepository(base.TestCase, zip_utils.ZipUtilsMixin):
 
 class TestRepositorySanity(TestCaseRepository):
 
-    @tag('all', 'coverage')
     @attr(type='smoke')
     def test_get_list_packages(self):
         resp, body = self.client.get_list_packages()
@@ -67,7 +73,6 @@ class TestRepositorySanity(TestCaseRepository):
         self.assertEqual(200, resp.status)
         self.assertTrue(isinstance(body['packages'], list))
 
-    @tag('all', 'coverage')
     @attr(type='smoke')
     def test_get_list_categories(self):
         resp, body = self.client.list_categories()
@@ -75,19 +80,18 @@ class TestRepositorySanity(TestCaseRepository):
         self.assertEqual(200, resp.status)
         self.assertTrue(isinstance(body['categories'], list))
 
-    @tag('all', 'coverage')
     @attr(type='smoke')
     def test_upload_and_delete_package(self):
         packages_list = self.client.get_list_packages()[1]
         for package in packages_list['packages']:
             if 'Dummy' in package['fully_qualified_name']:
                 self.client.delete_package(package['id'])
-
+        categorie = self.client.list_categories()[1]['categories'][0]
         packages_list = self.client.get_list_packages()[1]['packages']
 
         resp = self.client.upload_package(
             'testpackage',
-            {"categories": [], "tags": []})
+            {"categories": [categorie], "tags": ["windows"]})
         self.packages.append(resp.json())
 
         _packages_list = self.client.get_list_packages()[1]['packages']
@@ -111,7 +115,6 @@ class TestRepositoryNegativeNotFound(base.NegativeTestCase):
 
         cls.id = uuid.uuid4().hex
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_update_package_with_incorrect_id(self):
 
@@ -128,35 +131,30 @@ class TestRepositoryNegativeNotFound(base.NegativeTestCase):
                           self.id,
                           post_body)
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_get_package_with_incorrect_id(self):
         self.assertRaises(exceptions.NotFound,
                           self.client.get_package,
                           self.id)
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_delete_package_with_incorrect_id(self):
         self.assertRaises(exceptions.NotFound,
                           self.client.delete_package,
                           self.id)
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_download_package_with_incorrect_id(self):
         self.assertRaises(exceptions.NotFound,
                           self.client.download_package,
                           self.id)
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_get_ui_definition_with_incorrect_id(self):
         self.assertRaises(exceptions.NotFound,
                           self.client.get_ui_definition,
                           self.id)
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_get_logo_with_incorrect_id(self):
         self.assertRaises(exceptions.NotFound,
@@ -192,9 +190,7 @@ class TestRepositoryNegativeForbidden(base.NegativeTestCase,
         super(TestRepositoryNegativeForbidden, cls).tearDownClass()
 
         cls.client.delete_package(cls.package['id'])
-        cls.purge_creds()
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_update_package_from_another_tenant(self):
         post_body = [
@@ -210,35 +206,30 @@ class TestRepositoryNegativeForbidden(base.NegativeTestCase,
                           self.package['id'],
                           post_body)
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_get_package_from_another_tenant(self):
         self.assertRaises(exceptions.Forbidden,
                           self.alt_client.get_package,
                           self.package['id'])
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_delete_package_from_another_tenant(self):
         self.assertRaises(exceptions.Forbidden,
                           self.alt_client.delete_package,
                           self.package['id'])
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_download_package_from_another_tenant(self):
         self.assertRaises(exceptions.Forbidden,
                           self.alt_client.download_package,
                           self.package['id'])
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_get_ui_definition_from_another_tenant(self):
         self.assertRaises(exceptions.Forbidden,
                           self.alt_client.get_ui_definition,
                           self.package['id'])
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_get_logo_from_another_tenant(self):
         self.assertRaises(exceptions.Forbidden,
@@ -266,7 +257,6 @@ class TestRepository(TestCaseRepository):
             {"categories": [self.categorie], "tags": ["windows"]}).json()
         self.packages.append(self.package)
 
-    @tag('all', 'coverage')
     @attr(type='smoke')
     def test_get_package(self):
         resp, body = self.client.get_package(self.package['id'])
@@ -274,7 +264,6 @@ class TestRepository(TestCaseRepository):
         self.assertEqual(200, resp.status)
         self.assertEqual(self.package['tags'], body['tags'])
 
-    @tag('all', 'coverage')
     @attr(type='smoke')
     def test_update_package(self):
         post_body = [
@@ -369,21 +358,18 @@ class TestRepository(TestCaseRepository):
         self.assertEqual(200, resp.status)
         self.assertEqual("New name", body['name'])
 
-    @tag('all', 'coverage')
     @attr(type='smoke')
     def test_download_package(self):
         resp = self.client.download_package(self.package['id'])[0]
 
         self.assertEqual(200, resp.status)
 
-    @tag('all', 'coverage')
     @attr(type='smoke')
     def test_get_ui_definitions(self):
         resp = self.client.get_ui_definition(self.package['id'])[0]
 
         self.assertEqual(200, resp.status)
 
-    @tag('all', 'coverage')
     @attr(type='smoke')
     def test_get_logo(self):
         resp, body = self.client.get_logo(self.package['id'])
