@@ -12,16 +12,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from nose.plugins.attrib import attr as tag
-from tempest.lib import exceptions
+import testtools
+
 from tempest.test import attr
+from tempest_lib import exceptions
 
 from murano.tests.functional.api import base
 
 
 class TestServices(base.TestCase):
 
-    @tag('all', 'coverage')
     @attr(type='smoke')
     def test_get_services_list(self):
         env = self.create_environment('test')
@@ -34,7 +34,6 @@ class TestServices(base.TestCase):
         self.assertEqual(resp.status, 200)
         self.assertTrue(isinstance(services_list, list))
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_get_services_list_without_env_id(self):
         env = self.create_environment('test')
@@ -46,7 +45,6 @@ class TestServices(base.TestCase):
                           None,
                           sess['id'])
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_get_services_list_after_delete_env(self):
         env = self.create_environment('test')
@@ -60,7 +58,6 @@ class TestServices(base.TestCase):
                           env['id'],
                           sess['id'])
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_get_services_list_after_delete_session(self):
         env = self.create_environment('test')
@@ -74,7 +71,6 @@ class TestServices(base.TestCase):
                           env['id'],
                           sess['id'])
 
-    @tag('all', 'coverage')
     @attr(type='smoke')
     def test_create_and_delete_demo_service(self):
         env = self.create_environment('test')
@@ -101,7 +97,6 @@ class TestServices(base.TestCase):
         self.assertEqual(resp.status, 200)
         self.assertEqual(len(services_list), len(services_list_))
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_create_demo_service_without_env_id(self):
         env = self.create_environment('test')
@@ -113,19 +108,17 @@ class TestServices(base.TestCase):
                           None,
                           sess['id'])
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_create_demo_service_without_sess_id(self):
         env = self.create_environment('test')
 
         self.client.create_session(env['id'])
 
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(exceptions.Forbidden,
                           self.create_demo_service,
                           env['id'],
                           "")
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_delete_demo_service_without_env_id(self):
         env = self.create_environment('test')
@@ -140,7 +133,6 @@ class TestServices(base.TestCase):
                           sess['id'],
                           service['?']['id'])
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_delete_demo_service_without_session_id(self):
         env = self.create_environment('test')
@@ -149,13 +141,12 @@ class TestServices(base.TestCase):
 
         service = self.create_demo_service(env['id'], sess['id'])[1]
 
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(exceptions.Forbidden,
                           self.client.delete_service,
                           env['id'],
                           "",
                           service['?']['id'])
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_double_delete_service(self):
         env = self.create_environment('test')
@@ -172,7 +163,6 @@ class TestServices(base.TestCase):
                           sess['id'],
                           service['?']['id'])
 
-    @tag('all', 'coverage')
     @attr(type='smoke')
     def test_get_service(self):
         env = self.create_environment('test')
@@ -188,7 +178,6 @@ class TestServices(base.TestCase):
         self.assertEqual(resp.status, 200)
         self.assertEqual(service, service_)
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_get_service_without_env_id(self):
         env = self.create_environment('test')
@@ -203,55 +192,58 @@ class TestServices(base.TestCase):
                           sess['id'],
                           service['?']['id'])
 
-    @tag('all', 'coverage')
-    @attr(type='smoke')
-    def test_get_services_without_sess_id(self):
+    @testtools.skip("https://bugs.launchpad.net/murano/+bug/1295573")
+    @attr(type='negative')
+    def test_get_service_without_sess_id(self):
         env = self.create_environment('test')
-        resp, body = self.client.get_services_list(env['id'], None)
-        self.assertEqual(resp.status, 200)
-        self.assertEqual([], body)
+
+        sess = self.client.create_session(env['id'])[1]
+
+        service = self.create_demo_service(env['id'], sess['id'])[1]
+
+        self.assertRaises(exceptions.Unauthorized,
+                          self.client.get_service,
+                          env['id'],
+                          "",
+                          service['?']['id'])
 
 
 class TestServicesTenantIsolation(base.NegativeTestCase):
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_get_list_services_in_env_from_another_tenant(self):
         env = self.create_environment('test')
         sess = self.client.create_session(env['id'])[1]
 
-        self.assertRaises(exceptions.Forbidden,
+        self.assertRaises(exceptions.Unauthorized,
                           self.alt_client.get_services_list, env['id'],
                           sess['id'])
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_create_service_in_env_from_another_tenant(self):
         env = self.create_environment('test')
         sess = self.client.create_session(env['id'])[1]
 
-        self.assertRaises(exceptions.Forbidden,
+        self.assertRaises(exceptions.Unauthorized,
                           self.create_demo_service, env['id'],
                           sess['id'], client=self.alt_client)
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_delete_service_in_env_from_another_tenant(self):
         env = self.create_environment('test')
         sess = self.client.create_session(env['id'])[1]
         service = self.create_demo_service(env['id'], sess['id'])[1]
 
-        self.assertRaises(exceptions.Forbidden,
+        self.assertRaises(exceptions.Unauthorized,
                           self.alt_client.delete_service, env['id'],
                           sess['id'], service['?']['id'])
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_get_service_in_env_from_another_tenant(self):
         env = self.create_environment('test')
         sess = self.client.create_session(env['id'])[1]
         service = self.create_demo_service(env['id'], sess['id'])[1]
 
-        self.assertRaises(exceptions.Forbidden,
+        self.assertRaises(exceptions.Unauthorized,
                           self.alt_client.get_service, env['id'],
                           sess['id'], service['?']['id'])
